@@ -47,6 +47,11 @@ func NewDownloadCmd(f *cmdutil.Factory, runF func(*Options) error) *cobra.Comman
 			Any associated bundle(s) will be written to a file in the
 			current directory named after the artifact's digest. For example, if the
 			digest is "sha256:1234", the file will be named "sha256:1234.jsonl".
+
+			Colons are special characters on Windows and cannot be used in
+			file names. To accommodate, a dash will be used to separate the algorithm
+			from the digest in the attestations file name. For example, if the digest
+			is "sha256:1234", the file will be named "sha256-1234.jsonl".
 		`, "`"),
 		Example: heredoc.Doc(`
 			# Download attestations for a local artifact linked with an organization
